@@ -225,6 +225,10 @@ func (p *Postgres) processPaths(tx *gorm.DB, ipsw *model.Ipsw) error {
 		uniquePaths[fs.Path.Path] = struct{}{}
 	}
 
+	if len(uniquePaths) == 0 {
+		return nil
+	}
+
 	// Process paths in batches
 	paths := make([]string, 0, len(uniquePaths))
 	for path := range uniquePaths {
@@ -311,6 +315,10 @@ func (p *Postgres) processNames(tx *gorm.DB, ipsw *model.Ipsw) error {
 		}
 	}
 
+	if len(uniqueNames) == 0 {
+		return nil
+	}
+
 	// Process names in batches
 	names := make([]string, 0, len(uniqueNames))
 	for name := range uniqueNames {
